datajure.concise

Opt-in short aliases for power users. Refer the symbols you want: (require '[datajure.concise :refer [mn sm mx mi N dt fst lst wa ws]])

Aggregation helpers (operate on column vectors — use in :agg plain fns or directly): mn = mean sm = sum md = median sd = standard-deviation ct = count (element count) nuniq = count-distinct fst = first-val (first element) lst = last-val (last element) wa = wavg (weighted average) ws = wsum (weighted sum) mx = max* (column maximum) mi = min* (column minimum)

Statistical transforms (use inside #dt/e expressions as stat/* — these are direct refs to the runtime fns, useful outside #dt/e): standardize = stat/stat-standardize demean = stat/stat-demean winsorize = stat/stat-winsorize

Column selectors: between = positional range selector (core/between)

Everything else re-exported from datajure.core: N, dt, asc, desc, rename, pass-nil

Opt-in short aliases for power users.
Refer the symbols you want: (require '[datajure.concise :refer [mn sm mx mi N dt fst lst wa ws]])

Aggregation helpers (operate on column vectors — use in :agg plain fns or directly):
  mn    = mean
  sm    = sum
  md    = median
  sd    = standard-deviation
  ct    = count (element count)
  nuniq = count-distinct
  fst   = first-val (first element)
  lst   = last-val (last element)
  wa    = wavg (weighted average)
  ws    = wsum (weighted sum)
  mx    = max* (column maximum)
  mi    = min* (column minimum)

Statistical transforms (use inside #dt/e expressions as stat/* — these are
direct refs to the runtime fns, useful outside #dt/e):
  standardize = stat/stat-standardize
  demean      = stat/stat-demean
  winsorize   = stat/stat-winsorize

Column selectors:
  between = positional range selector (core/between)

Everything else re-exported from datajure.core:
  N, dt, asc, desc, rename, pass-nil
raw docstring

ascclj

Ascending sort spec. Re-exported from datajure.core/asc.

Ascending sort spec. Re-exported from `datajure.core/asc`.
sourceraw docstring

betweenclj

Between column selector. Re-exported from datajure.core/between. Returns a selector map for use with :select in dt. Example: (dt ds :select (between :month-01 :month-12))

Between column selector. Re-exported from `datajure.core/between`.
Returns a selector map for use with :select in dt.
Example: (dt ds :select (between :month-01 :month-12))
sourceraw docstring

ctclj

Element count. Short alias for dtype/ecount.

Element count. Short alias for `dtype/ecount`.
sourceraw docstring

demeanclj

Demean a column: x - mean(x). Delegates to stat/stat-demean.

Demean a column: x - mean(x). Delegates to `stat/stat-demean`.
sourceraw docstring

descclj

Descending sort spec. Re-exported from datajure.core/desc.

Descending sort spec. Re-exported from `datajure.core/desc`.
sourceraw docstring

dtclj

Main query function. Re-exported from datajure.core/dt.

Main query function. Re-exported from `datajure.core/dt`.
sourceraw docstring

fstclj

First value in a column. Delegates to expr/first-val.

First value in a column. Delegates to `expr/first-val`.
sourceraw docstring

lstclj

Last value in a column. Delegates to expr/last-val.

Last value in a column. Delegates to `expr/last-val`.
sourceraw docstring

mdclj

Column median. Short alias for core/median.

Column median. Short alias for `core/median`.
sourceraw docstring

miclj

Column minimum. Short alias for core/min*.

Column minimum. Short alias for `core/min*`.
sourceraw docstring

mnclj

Column mean. Short alias for core/mean.

Column mean. Short alias for `core/mean`.
sourceraw docstring

mxclj

Column maximum. Short alias for core/max*.

Column maximum. Short alias for `core/max*`.
sourceraw docstring

Nclj

Row count helper. Re-exported from datajure.core/N.

Row count helper. Re-exported from `datajure.core/N`.
sourceraw docstring

nuniqclj

Count of distinct values. Delegates to expr/count-distinct.

Count of distinct values. Delegates to `expr/count-distinct`.
sourceraw docstring

pass-nilclj

Nil-safe function wrapper. Re-exported from datajure.core/pass-nil.

Nil-safe function wrapper. Re-exported from `datajure.core/pass-nil`.
sourceraw docstring

renameclj

Rename columns. Re-exported from datajure.core/rename.

Rename columns. Re-exported from `datajure.core/rename`.
sourceraw docstring

sdclj

Column standard deviation. Short alias for core/stddev.

Column standard deviation. Short alias for `core/stddev`.
sourceraw docstring

smclj

Column sum. Short alias for core/sum.

Column sum. Short alias for `core/sum`.
sourceraw docstring

standardizeclj

Standardize a column: (x - mean) / sd. Delegates to stat/stat-standardize.

Standardize a column: (x - mean) / sd. Delegates to `stat/stat-standardize`.
sourceraw docstring

waclj

Weighted average. Delegates to expr/wavg. Args: weight-col value-col.

Weighted average. Delegates to `expr/wavg`. Args: weight-col value-col.
sourceraw docstring

winsorizeclj

Winsorize a column at tail probability p. Delegates to stat/stat-winsorize. Args: col p.

Winsorize a column at tail probability p. Delegates to `stat/stat-winsorize`. Args: col p.
sourceraw docstring

wsclj

Weighted sum. Delegates to expr/wsum. Args: weight-col value-col.

Weighted sum. Delegates to `expr/wsum`. Args: weight-col value-col.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries