Rich Clerk notebook viewers for Datajure datasets and expressions.
Usage — require and call install! at the top of your notebook:
(ns my-notebook (:require [datajure.clerk :as dc] [datajure.core :as core] [nextjournal.clerk :as clerk])) (dc/install!)
This registers custom viewers that automatically render:
Rich Clerk notebook viewers for Datajure datasets and expressions.
Usage — require and call install! at the top of your notebook:
(ns my-notebook
(:require [datajure.clerk :as dc]
[datajure.core :as core]
[nextjournal.clerk :as clerk]))
(dc/install!)
This registers custom viewers that automatically render:
- tech.v3.dataset datasets as rich HTML tables with column types
- #dt/e AST nodes as readable expressions
- du/describe output with conditional formatting(ast->string node)Convert a #dt/e AST node to a readable string representation.
Convert a #dt/e AST node to a readable string representation.
(dataset->hiccup dataset)(dataset->hiccup dataset
{:keys [max-rows max-cols]
:or {max-rows max-display-rows max-cols max-display-cols}})Convert a dataset to a rich Hiccup table representation. Options: :max-rows — max rows to display (default 25) :max-cols — max columns to display (default 30)
Convert a dataset to a rich Hiccup table representation. Options: :max-rows — max rows to display (default 25) :max-cols — max columns to display (default 30)
Clerk viewer for tech.v3.dataset datasets.
Clerk viewer for tech.v3.dataset datasets.
(describe->hiccup desc-ds)Convert a du/describe result dataset to an enhanced Hiccup table. Highlights missing data counts and formats statistics.
Convert a du/describe result dataset to an enhanced Hiccup table. Highlights missing data counts and formats statistics.
Clerk viewer for du/describe output (datasets with :column as first col).
Clerk viewer for du/describe output (datasets with :column as first col).
(expr->hiccup node)Convert a #dt/e AST node to a rich Hiccup representation.
Convert a #dt/e AST node to a rich Hiccup representation.
Clerk viewer for #dt/e expression AST nodes.
Clerk viewer for #dt/e expression AST nodes.
(install!)Register Datajure custom viewers with Clerk. Call at the top of your notebook after requiring this namespace.
The describe viewer is registered before the dataset viewer so that du/describe output gets enhanced formatting.
Register Datajure custom viewers with Clerk. Call at the top of your notebook after requiring this namespace. The describe viewer is registered before the dataset viewer so that du/describe output gets enhanced formatting.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |