Clojure only.

datajure.io

Unified file I/O for datajure. Dispatches on file extension. Natively supports: CSV, TSV, nippy (and .gz variants of all three). Parquet, xlsx/xls, and Arrow require optional extra dependencies.

Unified file I/O for datajure. Dispatches on file extension.
Natively supports: CSV, TSV, nippy (and .gz variants of all three).
Parquet, xlsx/xls, and Arrow require optional extra dependencies.
raw docstring

readclj

(read path)
(read path options)

Read a dataset from a file. Dispatches on file extension.

Natively supported: .csv .tsv .nippy (and .gz variants). Optional deps required: .parquet .xlsx .xls .arrow .feather.

Options are passed through to the underlying tech.v3.dataset reader. Columns are returned as keywords by default (:key-fn keyword).

Examples: (read "data.csv") (read "data.parquet") (read "data.tsv.gz") (read "data.csv" {:separator \tab})

Read a dataset from a file. Dispatches on file extension.

Natively supported: .csv .tsv .nippy (and .gz variants).
Optional deps required: .parquet .xlsx .xls .arrow .feather.

Options are passed through to the underlying tech.v3.dataset reader.
Columns are returned as keywords by default (:key-fn keyword).

Examples:
  (read "data.csv")
  (read "data.parquet")
  (read "data.tsv.gz")
  (read "data.csv" {:separator \tab})
sourceraw docstring

read-seqclj

(read-seq path)
(read-seq path options)

Read a file as a lazy sequence of datasets (for large files). Currently supported for Parquet only.

Example: (read-seq "huge.parquet")

Read a file as a lazy sequence of datasets (for large files).
Currently supported for Parquet only.

Example:
  (read-seq "huge.parquet")
sourceraw docstring

writeclj

(write dataset path)
(write dataset path options)

Write a dataset to a file. Dispatches on file extension.

Natively supported: .csv .tsv .nippy (and .gz variants). Optional deps required: .parquet .xlsx.

Options are passed through to the underlying tech.v3.dataset writer.

Examples: (write ds "output.csv") (write ds "output.parquet") (write ds "output.tsv.gz") (write ds "output.csv" {:separator \tab})

Write a dataset to a file. Dispatches on file extension.

Natively supported: .csv .tsv .nippy (and .gz variants).
Optional deps required: .parquet .xlsx.

Options are passed through to the underlying tech.v3.dataset writer.

Examples:
  (write ds "output.csv")
  (write ds "output.parquet")
  (write ds "output.tsv.gz")
  (write ds "output.csv" {:separator \tab})
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries